@@ -93,10 +93,9 @@ def _read_complex_astype(dset, indices, dtype_out=np.complex64):
     dset_shape, indices = uvutils._get_dset_shape(dset, indices)
     output_array = np.empty(dset_shape, dtype=dtype_out)
     dtype_in = dset.dtype
-    with dset.astype(dtype_in):
-        # dset is indexed in native dtype, but is upcast upon assignment
-        output_array.real = uvutils._index_dset(dset["r"], indices)
-        output_array.imag = uvutils._index_dset(dset["i"], indices)
+    # dset is indexed in native dtype, but is upcast upon assignment
+    output_array.real = uvutils._index_dset(dset.astype(dtype_in)["r"], indices)
+    output_array.imag = uvutils._index_dset(dset.astype(dtype_in)["i"], indices)
 
     return output_array
 
@@ -129,13 +128,11 @@ def _write_complex_astype(data, dset, indices):
     _check_uvh5_dtype(dtype_out)
     if len(dset.shape) == 3:
         # this is the future array shape
-        with dset.astype(dtype_out):
-            dset[indices[0], indices[1], indices[2], "r"] = data.real
-            dset[indices[0], indices[1], indices[2], "i"] = data.imag
+        dset[indices[0], indices[1], indices[2], "r"] = data.real
+        dset[indices[0], indices[1], indices[2], "i"] = data.imag
     else:
-        with dset.astype(dtype_out):
-            dset[indices[0], np.s_[:], indices[1], indices[2], "r"] = data.real
-            dset[indices[0], np.s_[:], indices[1], indices[2], "i"] = data.imag
+        dset[indices[0], np.s_[:], indices[1], indices[2], "r"] = data.real
+        dset[indices[0], np.s_[:], indices[1], indices[2], "i"] = data.imag
     return
 
 
@@ -388,7 +385,11 @@ class UVH5(UVData):
                         header["extra_keywords"][key][()]
                     ).decode("utf8")
                 else:
-                    self.extra_keywords[key] = header["extra_keywords"][key][()]
+                    # special handling for empty datasets == python `None` type
+                    if header["extra_keywords"][key].shape is None:
+                        self.extra_keywords[key] = None
+                    else:
+                        self.extra_keywords[key] = header["extra_keywords"][key][()]
 
         if proc is not None:
             # if lsts are in the background wait for them to return
@@ -918,6 +919,15 @@ class UVH5(UVData):
             if not read_data:
                 # don't read in the data. This means the object is incomplete,
                 # but that may not matter for many purposes.
+
+                # run a check if desired before returning
+                if run_check:
+                    self.check(
+                        check_extra=check_extra,
+                        run_check_acceptability=run_check_acceptability,
+                        strict_uvw_antpos_check=strict_uvw_antpos_check,
+                    )
+
                 return
 
             # Now read in the data
@@ -1073,6 +1083,9 @@ class UVH5(UVData):
             for k in self.extra_keywords.keys():
                 if isinstance(self.extra_keywords[k], str):
                     extra_keywords[k] = np.string_(self.extra_keywords[k])
+                elif self.extra_keywords[k] is None:
+                    # save as empty/null dataset
+                    extra_keywords[k] = h5py.Empty("f")
                 else:
                     extra_keywords[k] = self.extra_keywords[k]
 
